@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -91,7 +91,9 @@ class HgTagDialog(QDialog, Ui_HgTagDialog):
         """
         Public method to retrieve the tag data.
         
-        @return tuple of two strings and int (tag, revision, tag operation)
+        @return tuple containing the tag, revision, tag operation and a flag
+            indicating to enforce the operation
+        @rtype tuple of str, str, int,bool
         """
         tag = self.tagCombo.currentText().replace(" ", "_")
         tagOp = 0
@@ -105,4 +107,5 @@ class HgTagDialog(QDialog, Ui_HgTagDialog):
                 tagOp = HgTagDialog.DeleteGlobalTag
             else:
                 tagOp = HgTagDialog.DeleteLocalTag
-        return (tag, self.revisionEdit.text(), tagOp)
+        return (tag, self.revisionEdit.text(), tagOp,
+                self.forceCheckBox.isChecked)
