@@ -102,7 +102,7 @@ class Visitor(object):
         self.__source = self.__source.replace("\r\n", "\n").replace("\r", "\n")
         
         # ensure source ends with an eol
-        if self.__source[-1] != '\n':
+        if bool(self.__source) and self.__source[-1] != '\n':
             self.__source = self.__source + '\n'
     
     def parse(self):
@@ -274,7 +274,7 @@ class Visitor(object):
                                   self.__file, var.line))
 
 
-def readmodule_ex(module, path=[]):
+def readmodule_ex(module, path=None):
     """
     Read a JavaScript file and return a dictionary of functions and variables.
 
@@ -284,7 +284,7 @@ def readmodule_ex(module, path=[]):
     """
     global _modules
     
-    dict = {}
+    dictionary = {}
 
     if module in _modules:
         # we've seen this file before...
@@ -292,24 +292,24 @@ def readmodule_ex(module, path=[]):
 
     # search the path for the file
     f = None
-    fullpath = list(path)
+    fullpath = [] if path is None else path[:]
     f, file, (suff, mode, type) = ClassBrowsers.find_module(module, fullpath)
     if f:
         f.close()
     if type not in SUPPORTED_TYPES:
         # not CORBA IDL source, can't do anything with this module
-        _modules[module] = dict
-        return dict
+        _modules[module] = dictionary
+        return dictionary
 
-    _modules[module] = dict
+    _modules[module] = dictionary
     try:
         src = Utilities.readEncodedFile(file)[0]
     except (UnicodeError, IOError):
         # can't do anything with this module
-        _modules[module] = dict
-        return dict
+        _modules[module] = dictionary
+        return dictionary
     
     visitor = Visitor(src, module, file)
-    dict = visitor.parse()
-    _modules[module] = dict
-    return dict
+    dictionary = visitor.parse()
+    _modules[module] = dictionary
+    return dictionary
